@@ -110,6 +110,7 @@ typedef struct _TotemEmbedded {
 	TotemStatusbar *statusbar;
 	TotemScrsaver *scrsaver;
 	int width, height;
+        char *user_agent;
 	const char *mimetype;
 	char *base_uri;
 	char *current_uri;
@@ -938,15 +939,47 @@ totem_embedded_set_playlist (TotemEmbedded *emb,
 			     GError **error)
 {
 	char *file_uri;
+	char *tmpfile;
+	GError *err = NULL;
+	GFile *src, *dst;
+	int fd;
 
 	g_message ("Setting the current playlist to %s (base: %s)",
 		   path, base_uri);
 
 	totem_embedded_clear_playlist (emb, NULL);
 
-	file_uri = g_filename_to_uri (path, NULL, error);
-	if (!file_uri)
-		return FALSE;
+	/* FIXME, we should remove that when we can
+	 * parse from memory or 
+	 * https://bugzilla.gnome.org/show_bug.cgi?id=598702 is fixed */
+	fd = g_file_open_tmp ("totem-browser-plugin-playlist-XXXXXX",
+			      &tmpfile,
+			      &err);
+	if (fd < 0) {
+		g_warning ("Couldn't open temporary file for playlist: %s",
+			   err->message);
+		g_error_free (err);
+		return TRUE;
+	}
+	src = g_file_new_for_path (path);
+	dst = g_file_new_for_path (tmpfile);
+	if (g_file_copy (src, dst, G_FILE_COPY_OVERWRITE, NULL, NULL, NULL, &err) == FALSE) {
+		g_warning ("Failed to copy playlist '%s' to '%s': %s",
+			   path, tmpfile, err->message);
+		g_error_free (err);
+		g_object_unref (src);
+		g_object_unref (dst);
+		g_free (tmpfile);
+		close (fd);
+		return TRUE;
+	}
+	g_free (tmpfile);
+
+	file_uri = g_file_get_uri (dst);
+
+	g_object_unref (src);
+	g_object_unref (dst);
+	close (fd);
 
 	totem_embedded_set_uri (emb, file_uri, base_uri, FALSE);
 	g_free (file_uri);
@@ -1710,14 +1743,12 @@ totem_embedded_construct (TotemEmbedded *emb,
 					       (-1, -1, type, &err));
 	}
 
-	/* FIXME! */
-	if (emb->bvw == NULL) {
-		/* FIXME! */
-		/* FIXME construct and show error message */
-		totem_embedded_error_and_exit (_("The Totem plugin could not be started."), err != NULL ? err->message : _("No reason."), emb);
-
-		if (err != NULL)
-			g_error_free (err);
+	/* FIXME: check the UA strings of the legacy plugins themselves */
+	/* FIXME: at least hxplayer seems to send different UAs depending on the protocol!? */
+	if (emb->user_agent != NULL) {
+                bacon_video_widget_set_user_agent (emb->bvw, emb->user_agent);
+		g_free (emb->user_agent);
+		emb->user_agent = NULL;
 	}
 
 	/* Fullscreen setup */
@@ -2028,6 +2059,7 @@ totem_embedded_push_parser (gpointer data)
 	TotemEmbedded *emb = (TotemEmbedded *) data;
 	TotemPlParser *parser;
 	TotemPlParserResult res;
+	GFile *file;
 
 	emb->parser_id = 0;
 
@@ -2040,6 +2072,12 @@ totem_embedded_push_parser (gpointer data)
 					       emb->base_uri, FALSE);
 	g_object_unref (parser);
 
+	/* Delete the temporary file created in
+	 * totem_embedded_set_playlist */
+	file = g_file_new_for_uri (emb->current_uri);
+	g_file_delete (file, NULL, NULL);
+	g_object_unref (file);
+
 	if (res != TOTEM_PL_PARSER_RESULT_SUCCESS) {
 		//FIXME show a proper error message
 		switch (res) {
@@ -2228,14 +2266,6 @@ int main (int argc, char **argv)
 		exit (1);
 	}
 
-	/* FIXME: check the UA strings of the legacy plugins themselves */
-	/* FIXME: at least hxplayer seems to send different UAs depending on the protocol!? */
-	if (arg_user_agent != NULL) {
-		g_setenv ("BACON_VIDEO_WIDGET_HTTP_USER_AGENT", arg_user_agent, TRUE);
-		g_free (arg_user_agent);
-		arg_user_agent = NULL;
-	}
-
 	bacon_video_widget_init_backend (NULL, NULL);
 
 	dbus_g_object_type_install_info (TOTEM_TYPE_EMBEDDED,
@@ -2283,6 +2313,7 @@ int main (int argc, char **argv)
 	emb->autostart = !arg_no_autostart;
 	emb->audioonly = arg_audioonly;
 	emb->type = arg_plugin_type;
+        emb->user_agent = arg_user_agent;
 
 	/* FIXME: register this BEFORE requesting the service name? */
 	dbus_g_connection_register_g_object
